[PATCH] osmo-gsm-tester[master]: cosmetic: use name 'mgw' instead of 'mgcpgw'

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

Neels Hofmeyr gerrit-no-reply at lists.osmocom.org
Tue Oct 31 00:43:05 UTC 2017


Review at  https://gerrit.osmocom.org/4601

cosmetic: use name 'mgw' instead of 'mgcpgw'

'mgcpgw' was a working title for the new 'osmo-mgw'. Rather use the name 'mgw' now.

Change-Id: Icf65bd1daa52b280d73e56b6267b3c81ed1c5487
---
R src/osmo_gsm_tester/osmo_mgw.py
M src/osmo_gsm_tester/osmo_msc.py
M src/osmo_gsm_tester/suite.py
R src/osmo_gsm_tester/templates/osmo-mgw.cfg.tmpl
M src/osmo_gsm_tester/templates/osmo-msc.cfg.tmpl
M suites/aoip_debug/interactive.py
M suites/aoip_encryption/register_a5_0_authopt.py
M suites/aoip_encryption/register_a5_0_authreq.py
M suites/aoip_encryption/register_a5_1_authreq.py
M suites/aoip_smpp/esme_connect_policy_acceptall.py
M suites/aoip_smpp/esme_connect_policy_closed.py
M suites/aoip_smpp/esme_ms_sms_storeforward.py
M suites/aoip_smpp/esme_ms_sms_transaction.py
M suites/aoip_sms/mo_mt_sms.py
M suites/voice/mo_mt_call.py
15 files changed, 55 insertions(+), 55 deletions(-)


  git pull ssh://gerrit.osmocom.org:29418/osmo-gsm-tester refs/changes/01/4601/1

diff --git a/src/osmo_gsm_tester/osmo_msc.py b/src/osmo_gsm_tester/osmo_msc.py
index 67234e3..a5e8585 100644
--- a/src/osmo_gsm_tester/osmo_msc.py
+++ b/src/osmo_gsm_tester/osmo_msc.py
@@ -34,12 +34,12 @@
     encryption = None
     authentication = None
 
-    def __init__(self, suite_run, hlr, mgcpgw, ip_address):
+    def __init__(self, suite_run, hlr, mgw, ip_address):
         super().__init__(log.C_RUN, 'osmo-msc_%s' % ip_address.get('addr'))
         self.suite_run = suite_run
         self.ip_address = ip_address
         self.hlr = hlr
-        self.mgcpgw = mgcpgw
+        self.mgw = mgw
         self.smsc = smsc.Smsc((ip_address.get('addr'), 2775))
 
     def start(self):
@@ -75,7 +75,7 @@
         values = dict(msc=config.get_defaults('msc'))
         config.overlay(values, self.suite_run.config())
         config.overlay(values, dict(msc=dict(ip_address=self.ip_address)))
-        config.overlay(values, self.mgcpgw.conf_for_msc())
+        config.overlay(values, self.mgw.conf_for_msc())
         config.overlay(values, self.hlr.conf_for_msc())
         config.overlay(values, self.smsc.get_config())
 
diff --git a/src/osmo_gsm_tester/suite.py b/src/osmo_gsm_tester/suite.py
index 28bdd69..fe9d3a2 100644
--- a/src/osmo_gsm_tester/suite.py
+++ b/src/osmo_gsm_tester/suite.py
@@ -25,7 +25,7 @@
 import pprint
 from . import config, log, template, util, resource, schema, ofono_client, event_loop, esme, sms
 from . import osmo_nitb
-from . import osmo_hlr, osmo_mgcpgw, osmo_msc, osmo_bsc, osmo_stp
+from . import osmo_hlr, osmo_mgw, osmo_msc, osmo_bsc, osmo_stp
 from . import test
 
 class Timeout(Exception):
@@ -322,15 +322,15 @@
             ip_address = self.ip_address()
         return osmo_hlr.OsmoHlr(self, ip_address)
 
-    def mgcpgw(self, ip_address=None, bts_ip=None):
+    def mgw(self, ip_address=None, bts_ip=None):
         if ip_address is None:
             ip_address = self.ip_address()
-        return osmo_mgcpgw.OsmoMgcpgw(self, ip_address, bts_ip)
+        return osmo_mgw.OsmoMgw(self, ip_address, bts_ip)
 
-    def msc(self, hlr, mgcpgw, ip_address=None):
+    def msc(self, hlr, mgw, ip_address=None):
         if ip_address is None:
             ip_address = self.ip_address()
-        return osmo_msc.OsmoMsc(self, hlr, mgcpgw, ip_address)
+        return osmo_msc.OsmoMsc(self, hlr, mgw, ip_address)
 
     def bsc(self, msc, ip_address=None):
         if ip_address is None:
diff --git a/src/osmo_gsm_tester/templates/osmo-mgcpgw.cfg.tmpl b/src/osmo_gsm_tester/templates/osmo-mgw.cfg.tmpl
similarity index 73%
rename from src/osmo_gsm_tester/templates/osmo-mgcpgw.cfg.tmpl
rename to src/osmo_gsm_tester/templates/osmo-mgw.cfg.tmpl
index 28a3798..699e912 100644
--- a/src/osmo_gsm_tester/templates/osmo-mgcpgw.cfg.tmpl
+++ b/src/osmo_gsm_tester/templates/osmo-mgw.cfg.tmpl
@@ -7,11 +7,11 @@
  logging level all debug
 line vty
   no login
-  bind ${mgcpgw.ip_address.addr}
+  bind ${mgw.ip_address.addr}
 mgcp
-  local ip ${mgcpgw.ip_address.addr}
-  bts ip ${mgcpgw.bts_ip}
-  bind ip ${mgcpgw.ip_address.addr}
+  local ip ${mgw.ip_address.addr}
+  bts ip ${mgw.bts_ip}
+  bind ip ${mgw.ip_address.addr}
   bind port 2427
   rtp base 4000
   rtp force-ptime 20
diff --git a/src/osmo_gsm_tester/templates/osmo-msc.cfg.tmpl b/src/osmo_gsm_tester/templates/osmo-msc.cfg.tmpl
index 89e73d0..9ac68b3 100644
--- a/src/osmo_gsm_tester/templates/osmo-msc.cfg.tmpl
+++ b/src/osmo_gsm_tester/templates/osmo-msc.cfg.tmpl
@@ -20,7 +20,7 @@
 cs7 instance 0
  point-code 0.0.1
 msc
- mgw remote-ip ${mgcpgw.ip_address.addr}
+ mgw remote-ip ${mgw.ip_address.addr}
  assign-tmsi
  cs7-instance-iu 0
  cs7-instance-a 0
diff --git a/suites/aoip_debug/interactive.py b/suites/aoip_debug/interactive.py
index 819f207..6d8db62 100755
--- a/suites/aoip_debug/interactive.py
+++ b/suites/aoip_debug/interactive.py
@@ -2,8 +2,8 @@
 from osmo_gsm_tester.test import *
 hlr = suite.hlr()
 bts = suite.bts()
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 bsc = suite.bsc(msc)
 stp = suite.stp()
 modems = suite.modems(int(prompt('How many modems?')))
@@ -11,7 +11,7 @@
 hlr.start()
 stp.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 
 bsc.bts_add(bts)
 bsc.start()
diff --git a/suites/aoip_encryption/register_a5_0_authopt.py b/suites/aoip_encryption/register_a5_0_authopt.py
index 0224ee0..dafdc54 100755
--- a/suites/aoip_encryption/register_a5_0_authopt.py
+++ b/suites/aoip_encryption/register_a5_0_authopt.py
@@ -3,8 +3,8 @@
 
 hlr = suite.hlr()
 bts = suite.bts()
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 bsc = suite.bsc(msc)
 stp = suite.stp()
 ms = suite.modem()
@@ -16,7 +16,7 @@
 hlr.start()
 stp.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 bsc.bts_add(bts)
 bsc.start()
 bts.start()
diff --git a/suites/aoip_encryption/register_a5_0_authreq.py b/suites/aoip_encryption/register_a5_0_authreq.py
index 114c628..49b8021 100755
--- a/suites/aoip_encryption/register_a5_0_authreq.py
+++ b/suites/aoip_encryption/register_a5_0_authreq.py
@@ -3,8 +3,8 @@
 
 hlr = suite.hlr()
 bts = suite.bts()
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 bsc = suite.bsc(msc)
 stp = suite.stp()
 ms = suite.modem()
@@ -16,7 +16,7 @@
 hlr.start()
 stp.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 bsc.bts_add(bts)
 bsc.start()
 bts.start()
diff --git a/suites/aoip_encryption/register_a5_1_authreq.py b/suites/aoip_encryption/register_a5_1_authreq.py
index a84fa3a..21ac1ef 100755
--- a/suites/aoip_encryption/register_a5_1_authreq.py
+++ b/suites/aoip_encryption/register_a5_1_authreq.py
@@ -3,8 +3,8 @@
 
 hlr = suite.hlr()
 bts = suite.bts()
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 bsc = suite.bsc(msc)
 stp = suite.stp()
 ms = suite.modem()
@@ -16,7 +16,7 @@
 hlr.start()
 stp.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 bsc.bts_add(bts)
 bsc.start()
 bts.start()
diff --git a/suites/aoip_smpp/esme_connect_policy_closed.py b/suites/aoip_smpp/esme_connect_policy_closed.py
index 29b25d1..ce07f9c 100755
--- a/suites/aoip_smpp/esme_connect_policy_closed.py
+++ b/suites/aoip_smpp/esme_connect_policy_closed.py
@@ -13,8 +13,8 @@
 
 hlr = suite.hlr()
 bts = suite.bts()
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 smsc = msc.smsc
 
 esme = suite.esme()
@@ -27,7 +27,7 @@
 
 hlr.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 
 log('Test with correct credentials (no password)')
 esme_no_pwd.connect()
diff --git a/suites/aoip_smpp/esme_ms_sms_storeforward.py b/suites/aoip_smpp/esme_ms_sms_storeforward.py
index 308ebf3..32dc68a 100755
--- a/suites/aoip_smpp/esme_ms_sms_storeforward.py
+++ b/suites/aoip_smpp/esme_ms_sms_storeforward.py
@@ -14,8 +14,8 @@
 
 hlr = suite.hlr()
 bts = suite.bts()
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 bsc = suite.bsc(msc)
 stp = suite.stp()
 bsc.bts_add(bts)
@@ -27,7 +27,7 @@
 hlr.start()
 stp.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 bsc.start()
 bts.start()
 
diff --git a/suites/aoip_smpp/esme_ms_sms_transaction.py b/suites/aoip_smpp/esme_ms_sms_transaction.py
index 8bcfb6b..cd677fa 100755
--- a/suites/aoip_smpp/esme_ms_sms_transaction.py
+++ b/suites/aoip_smpp/esme_ms_sms_transaction.py
@@ -12,8 +12,8 @@
 
 hlr = suite.hlr()
 bts = suite.bts()
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 bsc = suite.bsc(msc)
 stp = suite.stp()
 bsc.bts_add(bts)
@@ -25,7 +25,7 @@
 hlr.start()
 stp.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 bsc.start()
 bts.start()
 
diff --git a/suites/aoip_sms/mo_mt_sms.py b/suites/aoip_sms/mo_mt_sms.py
index 217d807..3ede47a 100755
--- a/suites/aoip_sms/mo_mt_sms.py
+++ b/suites/aoip_sms/mo_mt_sms.py
@@ -3,8 +3,8 @@
 
 hlr = suite.hlr()
 bts = suite.bts()
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 bsc = suite.bsc(msc)
 stp = suite.stp()
 ms_mo = suite.modem()
@@ -13,7 +13,7 @@
 hlr.start()
 stp.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 
 bsc.bts_add(bts)
 bsc.start()
diff --git a/suites/voice/mo_mt_call.py b/suites/voice/mo_mt_call.py
index f426037..fc5911f 100755
--- a/suites/voice/mo_mt_call.py
+++ b/suites/voice/mo_mt_call.py
@@ -3,8 +3,8 @@
 
 hlr = suite.hlr()
 bts = suite.bts()
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 bsc = suite.bsc(msc)
 stp = suite.stp()
 ms_mo = suite.modem()
@@ -13,7 +13,7 @@
 hlr.start()
 stp.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 
 bsc.bts_add(bts)
 bsc.start()

diff --git a/src/osmo_gsm_tester/osmo_mgcpgw.py b/src/osmo_gsm_tester/osmo_mgw.py
similarity index 79%
rename from src/osmo_gsm_tester/osmo_mgcpgw.py
rename to src/osmo_gsm_tester/osmo_mgw.py
index 93c3a7c..18b11ab 100644
--- a/src/osmo_gsm_tester/osmo_mgcpgw.py
+++ b/src/osmo_gsm_tester/osmo_mgw.py
@@ -1,4 +1,4 @@
 # osmo_gsm_tester: specifics for running an osmo-mgcp-gw (osmo-bsc_mgcp)
 #
 # Copyright (C) 2017 by sysmocom - s.f.m.c. GmbH
 #
@@ -22,7 +22,7 @@
 
 from . import log, util, config, template, process, osmo_ctrl, pcap_recorder
 
-class OsmoMgcpgw(log.Origin):
+class OsmoMgw(log.Origin):
     suite_run = None
     ip_address = None
     run_dir = None
@@ -30,14 +30,14 @@
     process = None
 
     def __init__(self, suite_run, ip_address, bts_ip):
-        super().__init__(log.C_RUN, 'osmo-mgcpgw_%s' % ip_address.get('addr'))
+        super().__init__(log.C_RUN, 'osmo-mgw_%s' % ip_address.get('addr'))
         self.suite_run = suite_run
         self.ip_address = ip_address
         # hack: so far mgcpgw needs one specific BTS IP.
         self.bts_ip = bts_ip
 
     def start(self):
-        self.log('Starting osmo-mgcpgw')
+        self.log('Starting osmo-mgw')
         self.run_dir = util.Dir(self.suite_run.get_test_run_dir().new_dir(self.name()))
         self.configure()
         inst = util.Dir(os.path.abspath(self.suite_run.trial.get_inst('osmo-mgw')))
@@ -63,17 +63,17 @@
         self.process.launch()
 
     def configure(self):
-        self.config_file = self.run_dir.new_file('osmo-mgcpgw.cfg')
+        self.config_file = self.run_dir.new_file('osmo-mgw.cfg')
         self.dbg(config_file=self.config_file)
 
-        values = dict(mgcpgw=config.get_defaults('mgcpgw'))
+        values = dict(mgw=config.get_defaults('mgw'))
         config.overlay(values, self.suite_run.config())
-        config.overlay(values, dict(mgcpgw=dict(ip_address=self.ip_address, bts_ip=self.bts_ip)))
+        config.overlay(values, dict(mgw=dict(ip_address=self.ip_address, bts_ip=self.bts_ip)))
 
-        self.dbg('MGCPGW CONFIG:\n' + pprint.pformat(values))
+        self.dbg('MGW CONFIG:\n' + pprint.pformat(values))
 
         with open(self.config_file, 'w') as f:
-            r = template.render('osmo-mgcpgw.cfg', values)
+            r = template.render('osmo-mgw.cfg', values)
             self.dbg(r)
             f.write(r)
 
@@ -81,7 +81,7 @@
         return self.ip_address.get('addr')
 
     def conf_for_msc(self):
-        return dict(mgcpgw=dict(ip_address=self.ip_address))
+        return dict(mgw=dict(ip_address=self.ip_address))
 
     def running(self):
         return not self.process.terminated()
@@ -1,4 +1,4 @@
-# osmo_gsm_tester: specifics for running an osmo-mgcp-gw (osmo-bsc_mgcp)
+# osmo_gsm_tester: specifics for running an osmo-mgw (osmo-bsc_mgcp)
 #
 # Copyright (C) 2017 by sysmocom - s.f.m.c. GmbH
@@ -30,14 +30,14 @@
         self.suite_run = suite_run
         self.ip_address = ip_address
-        # hack: so far mgcpgw needs one specific BTS IP.
+        # hack: so far mgw needs one specific BTS IP.
         self.bts_ip = bts_ip
 
diff --git a/suites/aoip_smpp/esme_connect_policy_acceptall.py b/suites/aoip_smpp/esme_connect_policy_acceptall.py
index 2a954d5..82d4f86 100755
--- a/suites/aoip_smpp/esme_connect_policy_acceptall.py
+++ b/suites/aoip_smpp/esme_connect_policy_acceptall.py
@@ -7,9 +7,9 @@
 from osmo_gsm_tester.test import *
 
 hlr = suite.hlr()
-bts = suite.bts() # bts not started, only needed for mgcpgw
-mgcpgw = suite.mgcpgw(bts_ip=bts.remote_addr())
-msc = suite.msc(hlr, mgcpgw)
+bts = suite.bts() # bts not started, only needed for mgw
+mgw = suite.mgw(bts_ip=bts.remote_addr())
+msc = suite.msc(hlr, mgw)
 smsc = msc.smsc
 esme = suite.esme()
 
@@ -20,7 +20,7 @@
 
 hlr.start()
 msc.start()
-mgcpgw.start()
+mgw.start()
 
 # Due to accept-all policy, connect() should work even if we didn't previously
 # configure the esme in the smsc, no matter the system_id / password we use.
-- 
To view, visit https://gerrit.osmocom.org/4601
To unsubscribe, visit https://gerrit.osmocom.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Icf65bd1daa52b280d73e56b6267b3c81ed1c5487
Gerrit-PatchSet: 1
Gerrit-Project: osmo-gsm-tester
Gerrit-Branch: master
Gerrit-Owner: Neels Hofmeyr <nhofmeyr at sysmocom.de>



More information about the gerrit-log mailing list